function _interopDefault (ex) { return (ex && (typeof ex === 'object') && 'default' in ex) ? ex['default'] : ex; }

var react = require('react');
var axios = _interopDefault(require('axios'));

function _extends() {
  _extends = Object.assign || function (target) {
    for (var i = 1; i < arguments.length; i++) {
      var source = arguments[i];

      for (var key in source) {
        if (Object.prototype.hasOwnProperty.call(source, key)) {
          target[key] = source[key];
        }
      }
    }

    return target;
  };

  return _extends.apply(this, arguments);
}

var LOADING = 'LOADING';
var SUCCESS = 'SUCCESS';
var ERROR = 'ERROR';

var PUT = "put";
var POST = "post";
var DELETE = "delete";

var initialfetchState = {
  data: null,
  loading: true,
  error: null
};
var initialMutationState = {
  data: null,
  loading: false,
  error: null
};

var fetchReducer = function fetchReducer(state, action) {
  var _action$payload;

  switch (action.type) {
    case LOADING:
      return _extends({}, state, {
        loading: true
      });

    case SUCCESS:
      return _extends({}, state, {
        loading: false,
        data: (_action$payload = action.payload) === null || _action$payload === void 0 ? void 0 : _action$payload.data,
        error: null
      });

    case ERROR:
      return _extends({}, state, {
        loading: false,
        error: action.error
      });

    default:
      return state;
  }
};

var mutationReducer = function mutationReducer(state, action) {
  var _action$payload2;

  switch (action.type) {
    case LOADING:
      return _extends({}, state, {
        loading: true
      });

    case SUCCESS:
      return _extends({}, state, {
        loading: false,
        data: (_action$payload2 = action.payload) === null || _action$payload2 === void 0 ? void 0 : _action$payload2.data,
        error: null
      });

    case ERROR:
      return _extends({}, state, {
        loading: false,
        error: action.error
      });

    default:
      return state;
  }
};

var useFetch = function useFetch(url, headers) {
  var _useReducer = react.useReducer(fetchReducer, initialfetchState),
      state = _useReducer[0],
      dispatch = _useReducer[1];

  react.useEffect(function () {
    axios.get(url, headers && {
      headers: headers
    }).then(function (resp) {
      dispatch({
        type: SUCCESS,
        payload: resp
      });
    })["catch"](function (err) {
      dispatch({
        type: ERROR,
        error: err.message
      });
    });
  }, [url]);

  var refetch = function refetch() {
    dispatch({
      type: LOADING
    });
    axios.get(url, headers && {
      headers: headers
    }).then(function (resp) {
      dispatch({
        type: SUCCESS,
        payload: resp
      });
    })["catch"](function (err) {
      dispatch({
        type: ERROR,
        error: err.message
      });
    });
  };

  return {
    data: state.data,
    loading: state.loading,
    error: state.error,
    refetch: refetch
  };
};

var useMutation = function useMutation(url, requestType, headers) {
  var _useReducer2 = react.useReducer(mutationReducer, initialMutationState),
      state = _useReducer2[0],
      dispatch = _useReducer2[1];

  var requestHandler = function requestHandler(body) {
    if (typeof body !== "object") {
      console.log("body must be an object");
      return;
    }

    dispatch({
      type: LOADING
    });

    if (requestType === POST) {
      axios.post(url, body, headers && {
        headers: headers
      }).then(function (resp) {
        dispatch({
          type: SUCCESS,
          payload: resp
        });
      })["catch"](function (error) {
        dispatch({
          type: ERROR,
          error: error.message
        });
      });
    }

    if (requestType === PUT) {
      axios.put(url, body, headers && {
        headers: headers
      }).then(function (resp) {
        dispatch({
          type: SUCCESS,
          payload: resp
        });
      })["catch"](function (error) {
        dispatch({
          type: ERROR,
          error: error.message
        });
      });
    }

    if (requestType === DELETE) {
      axios["delete"](url, {
        data: body,
        headers: headers && headers
      }).then(function (resp) {
        dispatch({
          type: SUCCESS,
          payload: resp
        });
      })["catch"](function (err) {
        dispatch({
          type: ERROR,
          error: err.message
        });
      });
    }
  };

  return {
    data: state.data,
    loading: state.loading,
    error: state.error,
    handleRequest: requestHandler
  };
};

exports.useFetch = useFetch;
exports.useMutation = useMutation;
//# sourceMappingURL=index.js.map
